@@ -25,26 +25,40 @@ our @EXPORT_OK = qw/
 /;
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
-sub jq_getsome {
-  my ($num_slots, $prio) = @_;
-  return () if defined $num_slots and $num_slots eq '0';
-  $num_slots ||= 1;
-  $prio ||= 'normal';
-  my @returned = ();
+sub _getsome {
+  my ($num_slots, $where) = @_;
+  return () if ((!defined $num_slots) or ($num_slots < 1));
+  return () if ((!defined $where) or (ref {} ne ref $where));
 
   my $rs = schema('netdisco')->resultset('Admin')
     ->search(
-      {status => 'queued', action => { -in => setting('job_prio')->{$prio} } },
-      {order_by => 'random()', rows => ($num_slots || 1)},
+      { status => 'queued', %$where },
+      { order_by => 'random()', rows => $num_slots },
     );
 
+  my @returned = ();
   while (my $job = $rs->next) {
       push @returned, App::Netdisco::Daemon::Job->new({ $job->get_columns });
   }
   return @returned;
 }
 
-sub jq_getsomep { return jq_getsome(shift, 'high') }
+sub jq_getsome {
+  return _getsome(shift,
+    { action => { -in => setting('job_prio')->{'normal'} } }
+  );
+}
+
+sub jq_getsomep {
+  return _getsome(shift, {
+    -or => [{
+        username => { '!=' => undef },
+        action => { -in => setting('job_prio')->{'normal'} },
+      },{
+        action => { -in => setting('job_prio')->{'high'} },
+    }],
+  });
+}
 
 sub jq_locked {
   my $fqdn = hostfqdn || 'localhost';
